/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {
dojo.provide("com.ibm.team.process.web.client.internal.ProcessClient");

dojo.require("com.ibm.team.repository.web.transport.ServiceRequest");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.transport.TeamServerClient");

// constants and aliases
var SERVICE_URI      = "com.ibm.team.process.internal.common.service.IProcessRestService";
var ServiceRequest   = com.ibm.team.repository.web.transport.ServiceRequest;
var TeamServerClient = com.ibm.team.repository.web.transport.TeamServerClient;

var ProcessClient    = com.ibm.team.process.web.client.internal.ProcessClient;

function getProcessAreasForUser(kwArgs, responseHandler) {
	if (!kwArgs.userId) {
		alert("ProcessClient#getProcessAreasForUser: Missing required param: " + kwArgs.userId);
		return;
	}
	
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getProcessAreasForUser", kwArgs);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getProcessAreasForUser = getProcessAreasForUser;

function getAllProjectAreas(responseHandler, args) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getAllProjectAreas", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getAllProjectAreas = getAllProjectAreas;

function getProjectAreaByUUID(args, responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getProjectAreaByUUID", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getProjectAreaByUUID = getProjectAreaByUUID;

function getProjectHierarchy(args, responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getProjectHierarchy", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getProjectHierarchy = getProjectHierarchy;

function getTeamAreaByUUID(args, responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getTeamAreaByUUID", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getTeamAreaByUUID = getTeamAreaByUUID;

function getProcessAreaHierarchies(responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getProcessAreaHierarchies");
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getProcessAreaHierarchies = getProcessAreaHierarchies;

function getHierarchyForTeamArea(args, responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getHierarchyForTeamArea", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getHierarchyForTeamArea = getHierarchyForTeamArea;

function getContributors(args, responseHandler) {
	if (!args.isLicenseSearch) {
		if (!args.searchTerm) {
			args.searchTerm = "%";
		}
		else {
			args.searchTerm = "%" + args.searchTerm + "%";
		}
	}
	if (args.pageSize == null) {
		args.pageSize = 50;
	}
	if (args.pageNum == null) {
		args.pageNum = 0;
	}
	if (args.filterOutUsers != null && args.filterOutUsers.length > 0) {
		args.filterOutUsers = dojo.toJson(args.filterOutUsers);		
	}
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getContributors", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getContributors = getContributors;

function getPredefinedProcesses(responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getPredefinedProcesses");
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getPredefinedProcesses = getPredefinedProcesses;

function getProjectDevelopmentLines(args, responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "getProjectDevelopmentLines", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.getProjectDevelopmentLines = getProjectDevelopmentLines;

function postContributor(args, responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "postContributor", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.postContributor = postContributor;

function postProjectArea(args, responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "postProjectArea", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.postProjectArea = postProjectArea;

function postTeamArea(args, responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "postTeamArea", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.postTeamArea = postTeamArea;

function deployPredefinedProcessDefinitions(responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "postDeployPredefinedProcessDefinitions");
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.deployPredefinedProcessDefinitions = deployPredefinedProcessDefinitions;

function postArchiveProjectArea(args, responseHandler) {
	var serviceRequest = new ServiceRequest(SERVICE_URI, "postArchiveProjectArea", args);
	
	TeamServerClient.invokeService(serviceRequest, responseHandler);
}

ProcessClient.postArchiveProjectArea = postArchiveProjectArea;

})();
